@@ -1,6 +1,20 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
+import os
 import subprocess
+from itertools import repeat
+
+from pathos.pools import ParallelPool, ProcessPool, SerialPool, ThreadPool
+from tqdm import tqdm
+
+
+def drawer(frame, fig, ufunc):
+    # proc = os.getpid()
+    # print('{} by process {}'.format(frame,proc))
+    ufunc(frame)
+    fig.canvas.draw()
+    canvas_string = fig.canvas.tostring_argb()
+    return canvas_string
 
 
 def ffmpeg_video(fig, update_func, points, fps, outf):
@@ -13,6 +27,7 @@ def ffmpeg_video(fig, update_func, points, fps, outf):
         fps (int): frames per second for output video
         outf (str): output video filename
     """
+    outf = "pathos.mp4"
     canvas_width, canvas_height = fig.canvas.get_width_height()
     cmdstring = (
         "ffmpeg",
@@ -31,14 +46,27 @@ def ffmpeg_video(fig, update_func, points, fps, outf):
         "5000k",
         "-vcodec",
         "mpeg4",
+        "-threads",
+        "12",
+        "-loglevel",
+        "quiet",
         outf,
     )
+
+    import time
+
+    x = time.time()
+
+    pool = SerialPool()
+    results = pool.imap(drawer, range(0, points), repeat(fig), repeat(update_func))
+
     p = subprocess.Popen(cmdstring, stdin=subprocess.PIPE)
 
-    for frame in range(points):
-        update_func(frame)
-        fig.canvas.draw()
-        string = fig.canvas.tostring_argb()
-        p.stdin.write(string)
+    for frame in tqdm(results, total=points):
+        p.stdin.write(frame)
 
     p.communicate()
+    pool.close()
+    pool.terminate()
+
+    print(time.time() - x)
